@@ -1,3 +1,5 @@
+import importlib.resources
+import itertools
 import locale
 import logging
 import os
@@ -8,11 +10,9 @@ import tempfile
 from pathlib import Path
 from subprocess import DEVNULL, PIPE, Popen, TimeoutExpired, check_output, run
 
-import pkg_resources
-
 __all__ = (
     "SUPPORTED_STEAM_RUNTIMES", "OS_RELEASE_PATHS", "lower_dict",
-    "is_steam_deck", "get_legacy_runtime_library_paths",
+    "is_steam_deck", "is_steamos", "get_legacy_runtime_library_paths",
     "get_host_library_paths", "RUNTIME_ROOT_GLOB_PATTERNS",
     "get_runtime_library_paths", "WINE_SCRIPT_TEMPLATE",
     "get_cache_dir", "create_wine_bin_dir", "run_command"
@@ -70,6 +70,24 @@ def is_steam_deck():
     return False
 
 
+def is_steamos():
+    """
+    Check if we're running on SteamOS 3 (or newer)
+    """
+    for path in OS_RELEASE_PATHS:
+        try:
+            lines = Path(path).read_text("utf-8").split("\n")
+        except FileNotFoundError:
+            continue
+
+        # This will not detect SteamOS 2 or older which are based on Debian
+        if "ID=steamos" in lines and "ID_LIKE=arch" in lines:
+            logger.info("The current device is running on SteamOS 3+")
+            return True
+
+    return False
+
+
 def get_legacy_runtime_library_paths(legacy_steam_runtime_path, proton_app):
     """
     Get LD_LIBRARY_PATH value to use when running a command using Steam Runtime
@@ -154,26 +172,18 @@ def get_runtime_library_paths(proton_app, use_bwrap=True):
     ])
 
 
-WINE_SCRIPT_TEMPLATE = Path(
-    pkg_resources.resource_filename(
-        "protontricks", "data/scripts/wine_launch.sh"
-    )
-).read_text(encoding="utf-8")
-WINESERVER_KEEPALIVE_SH_SCRIPT = Path(
-    pkg_resources.resource_filename(
-        "protontricks", "data/scripts/wineserver_keepalive.sh"
-    )
-).read_text(encoding="utf-8")
-WINESERVER_KEEPALIVE_BATCH_SCRIPT = Path(
-    pkg_resources.resource_filename(
-        "protontricks", "data/scripts/wineserver_keepalive.bat"
-    )
-).read_text(encoding="utf-8")
-BWRAP_LAUNCHER_SH_SCRIPT = Path(
-    pkg_resources.resource_filename(
-        "protontricks", "data/scripts/bwrap_launcher.sh"
-    )
-).read_text(encoding="utf-8")
+WINE_SCRIPT_TEMPLATE = importlib.resources.read_text(
+    "protontricks.data.scripts", "wine_launch.sh", encoding="utf-8"
+)
+WINESERVER_KEEPALIVE_SH_SCRIPT = importlib.resources.read_text(
+    "protontricks.data.scripts", "wineserver_keepalive.sh", encoding="utf-8"
+)
+WINESERVER_KEEPALIVE_BATCH_SCRIPT = importlib.resources.read_text(
+    "protontricks.data.scripts", "wineserver_keepalive.bat", encoding="utf-8"
+)
+BWRAP_LAUNCHER_SH_SCRIPT = importlib.resources.read_text(
+    "protontricks.data.scripts", "bwrap_launcher.sh", encoding="utf-8"
+)
 
 
 def get_cache_dir():
@@ -264,8 +274,8 @@ def _get_fixed_locale_env():
     """
     # We can assume the 'en_US.UTF-8' locale always exists on Steam Deck, but
     # we can't assume the same about other distros. Therefore, only attempt
-    # fixing the locale when running on a Steam Deck.
-    if not is_steam_deck():
+    # fixing the locale when running on a SteamOS 3+.
+    if not is_steamos():
         return {}
 
     supported_locales = run(
@@ -308,6 +318,118 @@ def _get_fixed_locale_env():
     return fixed_env
 
 
+_DLL_OVERRIDES = {
+    "beclient": "b,n",
+    "beclient_x64": "b,n",
+
+    # DXVK
+    "dxgi": "n",
+    "d3d9": "n",
+    "d3d10core": "n",
+    "d3d11": "n",
+
+    # vkd3d-proton
+    "d3d12": "n",
+    "d3d12core": "n",
+
+    # nvapi
+    "nvapi": "n",
+    "nvapi64": "n",
+    "nvofapi64": "n",
+    "nvcuda": "b"
+}
+
+_WINE_DEFAULT_ENV_VARS = {
+    "WINE_LARGE_ADDRESS_AWARE": "1",
+    "DXVK_ENABLE_NVAPI": "1",
+}
+
+def _get_proton_env(proton_app, steam_app, orig_env):
+    """
+    Return a dict of various Proton related environment variables.
+    These are mainly required to configure DXVK, vkd3d-proton and GStreamer
+    properly.
+
+    When using Proton proper, these are usually set by the `proton` launcher
+    script. The script is not designed for programmatic usage, so we'll have to
+    set them manually instead.
+
+    Some environment variables are not supported depending on the Python
+    version. We will err on the side of caution and check if preconditions are
+    met before attempting to set any environment variables; for example, Proton
+    installation must contain GStreamer directory in order to set GStreamer env
+    vars.
+    """
+    new_env = {}
+
+    dist_path = proton_app.proton_dist_path
+
+    # 1.Configure WINEDLLOVERRIDES
+    available_dlls = set([
+        file_.stem for file_
+        in itertools.chain(
+            (dist_path / "lib64").glob("**/*.dll"),
+            (dist_path / "lib").glob("**/*.dll")
+        )
+    ])
+
+    dll_overrides = {}
+
+    # Get existing DLL overrides. Note that multiple DLLs might be specified
+    # at once using ',' and the value might be empty. For example, the following
+    # is a valid WINEDLLOVERRIDES: dxgi,d3d9=n;d3d10core=b;d3d11=
+    for dll_override in orig_env.get("WINEDLLOVERRIDES", "").split(";"):
+        if "=" not in dll_override:
+            continue
+
+        settings, value = dll_override.split("=")
+        settings = settings.split(",")
+
+        for setting in settings:
+            dll_overrides[setting] = value
+
+    logger.debug(
+        "Following Wine DLL overrides already set: %s",
+        dll_overrides
+    )
+
+    # Set DLL overrides if the corresponding DLL file exists *and* if the user
+    # hasn't declared something else
+    for name, setting in _DLL_OVERRIDES.items():
+        is_available = name in available_dlls
+        is_set = name in dll_overrides
+
+        if is_available and not is_set:
+            logger.debug("Setting Wine DLL override: %s=%s", name, setting)
+            dll_overrides[name] = setting
+
+    new_env["WINEDLLOVERRIDES"] = ";".join(
+        f"{name}={setting}" for name, setting in dll_overrides.items()
+    )
+
+    # 2. Configure GStreamer
+    is_gstreamer_available = (dist_path / "lib/gstreamer-1.0").is_dir()
+
+    if is_gstreamer_available:
+        logger.debug("Setting GStreamer environment variables")
+
+        new_env["GST_PLUGIN_SYSTEM_PATH_1_0"] = (
+            f"{dist_path / 'lib64/gstreamer-1.0'}"
+            f":{dist_path / 'lib/gstreamer-1.0'}"
+        )
+        new_env["WINE_GST_REGISTRY_DIR"] = str(
+            steam_app.prefix_path.parent / "gstreamer-1.0"
+        )
+
+    # 3. Enable various env vars unless already set by user
+    for name, value in _WINE_DEFAULT_ENV_VARS.items():
+        if name not in orig_env:
+            logger.debug("Setting default env var: %s=%s", name, value)
+            new_env[name] = value
+
+    return new_env
+
+
 def _start_process(args, wait=False, **kwargs):
     """Start a new process and return a Popen instance
     """
@@ -396,6 +518,14 @@ def run_command(
     # Fix the locale for Steam Deck, if necessary
     wine_environ.update(_get_fixed_locale_env())
 
+    # Set various Proton related environment variables
+    wine_environ.update(
+        _get_proton_env(
+            proton_app=proton_app, steam_app=steam_app,
+            orig_env=wine_environ
+        )
+    )
+
     wine_bin_dir = None
     wine_environ["PROTONTRICKS_STEAM_RUNTIME"] = "off"
     if use_steam_runtime:
